# flashinfer_bench.data.Solution

```{eval-rst}
.. currentmodule:: flashinfer_bench.data

.. autopydantic_model:: Solution

.. autoclass:: SupportedLanguages
    :members:

.. autopydantic_model:: SourceFile

.. autopydantic_model:: BuildSpec
```
